@@ -1,6 +1,7 @@
 #' Prints question summary for two years
 #'
 #' @param question_summary data.frame, summarises selected question
+#' @noRd
 #'
 .print_two_year_summary <- function(question_summary) {
   message(paste(
@@ -10,7 +11,7 @@
   for (i in seq_len(nrow(question_summary))) {
     message(paste(
       "In", question_summary$year[i],
-      "it was asked in", question_summary$n[i], "regions"
-    ))
+      "it was asked in", question_summary$n[i],
+      "of the selected geographies"))
   }
 }
